@@ -2,15 +2,14 @@ sub save_chart
 {
 	my $chart = shift or die "Need a chart!";
 	my $name = shift or die "Need a name!";
-	local(*OUT);
 
 	my $ext = $chart->export_format;
 
-	open(OUT, ">$name.$ext") or 
-		die "Cannot open $name.$ext for write: $!";
-	binmode OUT;
-	print OUT $chart->gd->$ext();
-	close OUT;
+	open(my $out, '>', "$name.$ext") or
+		die "Cannot open '$name.$ext' for write: $!";
+	binmode $out;
+	print $out $chart->gd->$ext();
+	close $out;
 }
 
 1;
